#!/bin/bash
# Creación de usuarios por lotes

#Pide confirmación del proceso
function procesar
{
	# Se informa del proceso
	clear
	echo "Creación de usuarios por lotes"
	echo "=============================="
	echo
	echo "Se va a crear la siguiente estructura:"
	echo "Grupo: $GRUPO"
	echo "Nº usuarios: $NUMERO"
	echo
	echo "¿Desea continuar? (S/N)"
	read sino

	case $sino in
		s|S) 
			crearGrupo 
			crearUsuarios ;;
		n|N) exit 1 ;;
		*) procesar ;;
	esac
}

# Crea el nuevo grupo
function crearGrupo
{
	clear

	# Comprobar si el grupo existe previamente (fichero /etc/group)
	cut -d: -f1 /etc/group | grep "$GRUPO" > /dev/null
	OUT=$?

	if [ $OUT -eq 0 ];then
		echo "El grupo \"$GRUPO\" ya existe."
		echo
		echo "¿Desea continuar? (S/N)"
		read sino
		case $sino in
			s|S) echo "Usando grupo existente...";;
			n|N) exit 1 ;;
			*) crearGrupo ;;
	esac
	else
		#creación del grupo
		echo "Creando nuevo grupo: $GRUPO"
		/usr/sbin/groupadd $GRUPO
	fi
}

# Crea los usuarios
function crearUsuarios
{
	echo
	echo "Creando usuarios..."

	#El nombre de usuario se forma como el nombre del grupo menos el último carácter
	prefijo=${GRUPO:0:${#GRUPO}-1}
	
	#Contador de usuarios creados
	let creados=0
	#contador de intentos de creación
	let intentos=0

	while ( test $creados -lt $NUMERO )
	do
		# Comprobar si el usuario existe previamente (fichero /etc/passwd)
		usuario="$prefijo$intentos" #comillas concatenan
		echo "Comprobando $usuario"
		cut -d: -f1 /etc/passwd | grep "$usuario" > /dev/null
		OUT=$?
		if [ $OUT -eq 0 ] ; then
			echo "El usuario Usuario $usuario ya existe"
			echo "Se creará un nuevo usuario secuencial"
		else
			#se crea el nuevo usuario
			echo "Creando nuevo usuario: $usuario"
			/usr/sbin/useradd -g $GRUPO $usuario
			#se le asigna la contraseña
			sufijo="__"
			pass="$usuario$sufijo"
			echo "Asignando contraseña $pass a $usuario"
			echo $pass | passwd --stdin $usuario
			#se incrementa el número de usuarios creados
			let creados=creados+1
		fi
		#se incrementa el número de intentos
		let intentos=intentos+1
	done	
}


############### PROGRAMA PRINCIPAL ###################

# Debe ser superusuario para poder ejecutar el script
if [ $UID -ne 0 ]; then
	echo "Debe ejecutar $0 como Root."
	exit 1
fi

